"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExecResolver = void 0;

var _core = require("@yarnpkg/core");

var _fslib = require("@yarnpkg/fslib");

var _constants = require("./constants");

class ExecResolver {
  supportsDescriptor(descriptor, opts) {
    if (!descriptor.range.startsWith(_constants.PROTOCOL)) return false;
    return true;
  }

  supportsLocator(locator, opts) {
    if (!locator.reference.startsWith(_constants.PROTOCOL)) return false;
    return true;
  }

  shouldPersistResolution(locator, opts) {
    return false;
  }

  bindDescriptor(descriptor, fromLocator, opts) {
    return _core.structUtils.bindDescriptor(descriptor, {
      locator: _core.structUtils.stringifyLocator(fromLocator)
    });
  }

  getResolutionDependencies(descriptor, opts) {
    return [];
  }

  async getCandidates(descriptor, dependencies, opts) {
    let path = descriptor.range;
    if (path.startsWith(_constants.PROTOCOL)) path = path.slice(_constants.PROTOCOL.length);
    return [_core.structUtils.makeLocator(descriptor, `${_constants.PROTOCOL}${_fslib.npath.toPortablePath(path)}`)];
  }

  async resolve(locator, opts) {
    if (!opts.fetchOptions) throw new Error(`Assertion failed: This resolver cannot be used unless a fetcher is configured`);
    const packageFetch = await opts.fetchOptions.fetcher.fetch(locator, opts.fetchOptions);
    const manifest = await _core.miscUtils.releaseAfterUseAsync(async () => {
      return await _core.Manifest.find(packageFetch.prefixPath, {
        baseFs: packageFetch.packageFs
      });
    }, packageFetch.releaseFs);
    return { ...locator,
      version: manifest.version || `0.0.0`,
      languageName: opts.project.configuration.get(`defaultLanguageName`),
      linkType: _core.LinkType.HARD,
      dependencies: manifest.dependencies,
      peerDependencies: manifest.peerDependencies,
      dependenciesMeta: manifest.dependenciesMeta,
      peerDependenciesMeta: manifest.peerDependenciesMeta,
      bin: manifest.bin
    };
  }

}

exports.ExecResolver = ExecResolver;